% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/es_from_PAIRED_MC.R
\name{es_from_mean_change_pval}
\alias{es_from_mean_change_pval}
\title{Convert mean changes and standard deviations of two independent groups into standard effect size measures}
\usage{
es_from_mean_change_pval(
  mean_change_exp,
  mean_change_pval_exp,
  mean_change_nexp,
  mean_change_pval_nexp,
  r_pre_post_exp,
  r_pre_post_nexp,
  n_exp,
  n_nexp,
  smd_to_cor = "viechtbauer",
  reverse_mean_change
)
}
\arguments{
\item{mean_change_exp}{mean change of participants in the experimental/exposed group.}

\item{mean_change_pval_exp}{p-value of the mean change for participants in the experimental/exposed group.}

\item{mean_change_nexp}{mean change of participants in the non-experimental/non-exposed group.}

\item{mean_change_pval_nexp}{p-value of the mean change for participants in the non-experimental/non-exposed group.}

\item{r_pre_post_exp}{pre-post correlation in the experimental/exposed group}

\item{r_pre_post_nexp}{pre-post correlation in the non-experimental/non-exposed group}

\item{n_exp}{number of participants in the experimental/exposed group.}

\item{n_nexp}{number of participants in the non-experimental/non-exposed group.}

\item{smd_to_cor}{formula used to convert the \code{cohen_d} value into a coefficient correlation (see details).}

\item{reverse_mean_change}{a logical value indicating whether the direction of generated effect sizes should be flipped.}
}
\value{
This function estimates and converts between several effect size measures.

\tabular{ll}{
\code{natural effect size measure} \tab MD + D + G\cr
\tab \cr
\code{converted effect size measure} \tab OR + R + Z \cr
\tab \cr
\code{required input data} \tab See 'Section 14. Paired: mean change, and dispersion'\cr
\tab https://metaconvert.org/input.html\cr
\tab \cr
}
}
\description{
Convert mean changes and standard deviations of two independent groups into standard effect size measures
}
\details{
This function converts the mean change and associated p-values of two independent groups
into a Cohen's d. The Cohen's d is then converted to other effect size measures.

To start, this function estimates the mean change standard errors from the p-values:
\deqn{t\_exp <- qt(p = mean\_change\_pval\_exp / 2, df = n\_exp - 1, lower.tail = FALSE)}
\deqn{t\_nexp <- qt(p = mean\_change\_pval\_nexp / 2, df = n\_nexp - 1, lower.tail = FALSE)}
\deqn{mean\_change\_se\_exp <- |\frac{mean\_change\_exp}{t\_exp}|}
\deqn{mean\_change\_se\_nexp <- |\frac{mean\_change\_nexp}{t\_nexp}|}
Then, this function simply internally calls the \code{\link{es_from_means_se_pre_post}} function but setting:
\deqn{mean\_pre\_exp = mean\_change\_exp}
\deqn{mean\_pre\_se\_exp = mean\_change\_se\_exp}
\deqn{mean\_exp = 0}
\deqn{mean\_se\_exp = 0}
\deqn{mean\_pre\_nexp = mean\_change\_nexp}
\deqn{mean\_pre\_se\_nexp = mean\_change\_se\_nexp}
\deqn{mean\_nexp = 0}
\deqn{mean\_se\_nexp = 0}

To know more about other calculations, see \code{\link{es_from_means_sd_pre_post}} function.
}
\examples{
es_from_mean_change_pval(
  n_exp = 36, n_nexp = 35,
  mean_change_exp = 8.4, mean_change_pval_exp = 0.13,
  mean_change_nexp = 2.43, mean_change_pval_nexp = 0.61,
  r_pre_post_exp = 0.8, r_pre_post_nexp = 0.8
)
}
\references{
Bonett, S. B. (2008). Estimating effect sizes from pretest-posttest-control group designs. Organizational Research Methods, 11(2), 364–386. https://doi.org/10.1177/1094428106291059

Cooper, H., Hedges, L.V., & Valentine, J.C. (Eds.). (2019). The handbook of research synthesis and meta-analysis. Russell Sage Foundation.
}
